xl
==

*xml without mess.*

This is a Python module to process XML.



Why I am coding this?
---------------------
* lxml supports sub text node not clear enough.
* xml.etree.ElementTree doesn't care XML namespaces.
* I want to learn XML.



.. automodule:: epubaker.xl
    :members: parse, clean_whitespaces, pretty_insert

.. autoclass:: Xl
    :members:

.. autoclass:: Header
    :members:

.. autoclass:: DocType
    :members:

.. autoclass:: Element
    :members:
